@@ -27,7 +27,7 @@ from email import charset
 charset.add_charset('utf-8', None)
 emlpolicy = email.policy.EmailPolicy(utf8=True, cte_type='8bit', max_line_length=None)
 
-__VERSION__ = '0.4.1'
+__VERSION__ = '0.4.3'
 ATTESTATION_FORMAT_VER = '0.1'
 
 logger = logging.getLogger('b4')
@@ -275,8 +275,11 @@ class LoreMailbox:
                 if pmsg is None:
                     # Can't find the message we're replying to here
                     continue
-            else:
+            elif fmsg.in_reply_to in self.msgid_map:
                 pmsg = self.msgid_map[fmsg.in_reply_to]
+            else:
+                logger.debug('  missing message, skipping: %s', fmsg.in_reply_to)
+                continue
 
             trailers, mismatches = fmsg.get_trailers(sloppy=sloppytrailers)
             for tname, tvalue in mismatches:
@@ -679,7 +682,13 @@ class LoreMessage:
             pcharset = part.get_content_charset()
             if not pcharset:
                 pcharset = mcharset
-            payload = payload.decode(pcharset, errors='replace')
+            try:
+                payload = payload.decode(pcharset, errors='replace')
+            except LookupError:
+                # what kind of encoding is that?
+                # Whatever, we'll use utf-8 and hope for the best
+                payload = payload.decode('utf-8', errors='replace')
+                part.set_param('charset', 'utf-8')
             if self.body is None:
                 self.body = payload
                 continue
